@@ -8,7 +8,7 @@ role = silk.lib.get_role()
 root = silk.lib.get_site_root(os.getcwd())
 config = silk.lib.get_config(root, role)
 
-if config['static_dirs']:
+if config.get('static_dirs'):
     for static_dir in config['static_dirs']:
         # Mount each of our static dirs as its own app in the cherrypy tree.
         # Each static_dir is a dict with url_path and system_path keys
